summaryrefslogtreecommitdiff
path: root/libcons/opts-std-startup.c
diff options
context:
space:
mode:
Diffstat (limited to 'libcons/opts-std-startup.c')
-rw-r--r--libcons/opts-std-startup.c78
1 files changed, 74 insertions, 4 deletions
diff --git a/libcons/opts-std-startup.c b/libcons/opts-std-startup.c
index 29278cc2..3cf81ae7 100644
--- a/libcons/opts-std-startup.c
+++ b/libcons/opts-std-startup.c
@@ -1,5 +1,5 @@
/* opts-std-startup.c - Standard startup-time command line parser.
- Copyright (C) 1995,96,97,98,99,2001,02,2003 Free Software Foundation, Inc.
+ Copyright (C) 1995,96,97,98,99,2001,02,2003,2004,2005 Free Software Foundation, Inc.
Written by Miles Bader <miles@gnu.org> and Marcus Brinkmann.
This file is part of the GNU Hurd.
@@ -25,7 +25,7 @@
#include "priv.h"
/* Option keys for long-only options in diskfs_common_options. */
#define OPT_SLACK 600 /* --slack */
#define OPT_JUMP_DOWN_ON_INPUT 601 /* --jump-down-on-input */
#define OPT_NO_JUMP_DOWN_ON_INPUT 602 /* --no-jump-down-on-input */
@@ -33,13 +33,20 @@
#define OPT_NO_JUMP_DOWN_ON_OUTPUT 604 /* --no-jump-down-on-output */
#define OPT_VISUAL_BELL 605 /* --visual-bell */
#define OPT_AUDIBLE_BELL 606 /* --audible-bell */
+#define OPT_MOUSE_SHOW 607 /* --mouse-show-on */
+#define OPT_MOUSE_HIDE 608 /* --mouse-hide-on */
+#define OPT_MOUSE_SENS 609 /* --mouse-sensitivity */
-/* Common value for diskfs_common_options and diskfs_default_sync_interval. */
+/* The number of records the client is allowed to lag behind the server. */
#define DEFAULT_SLACK 100
#define DEFAULT_SLACK_STRING STRINGIFY(DEFAULT_SLACK)
#define STRINGIFY(x) STRINGIFY_1(x)
#define STRINGIFY_1(x) #x
+/* The mouse sensitivity. */
+#define DEFAULT_MOUSE_SENS 3.0
+#define DEFAULT_MOUSE_SENS_STRING STRINGIFY(DEFAULT_MOUSE_SENS)
+
/* Number of records the client is allowed to lag behind the
server. */
int _cons_slack = DEFAULT_SLACK;
@@ -59,6 +66,15 @@ bell_type_t _cons_visual_bell = BELL_VISUAL;
/* The type of bell used for the audible bell. */
bell_type_t _cons_audible_bell = BELL_AUDIBLE;
+/* The type of events that will make the mouse cursor visible. */
+int _cons_show_mouse = CONS_EVT_MOUSE_MOVE;
+
+/* The type of events that will hide the mouse cursor. */
+int _cons_hide_mouse = CONS_EVT_KEYPRESS;
+
+/* The mouse sensitivity. */
+float _cons_mouse_sens = DEFAULT_MOUSE_SENS;
+
static const struct argp_option
startup_options[] =
{
@@ -76,6 +92,15 @@ startup_options[] =
"off, visual, audible" },
{ "audible-bell", OPT_AUDIBLE_BELL, "BELL", 0, "Audible bell: on (default), "
"off, visual, audible" },
+ { "mouse-show-on", OPT_MOUSE_SHOW, "EVENTS", 0, "One or more of the events"
+ " mousemove, mousebutton, keypress, output (default is mousemove), if one"
+ " of these events occur the mouse cursor will be made visible" },
+ { "mouse-hide-on", OPT_MOUSE_HIDE, "EVENTS", 0, "One or more of the events"
+ " mousemove, mousebutton, keypress, output (default is keypress), if one"
+ " of these events occur the mouse cursor will be hidden " },
+ { "mouse-sensitivity", OPT_MOUSE_SENS, "SENSITIVITY", 0, "The mouse"
+ " sensitivity (default " DEFAULT_MOUSE_SENS_STRING "). A lower value"
+ " means more sensitive" },
{ 0, 0 }
};
@@ -86,6 +111,30 @@ static const char doc[] = "A console client.";
static error_t
parse_startup_opt (int opt, char *arg, struct argp_state *state)
{
+ int parse_events (char *events)
+ {
+ char *evtstr = strdupa (events);
+ char *tok = strtok (evtstr, ",");
+ int evmask = 0;
+
+ while (tok)
+ {
+ if (!strcasecmp ("mousemove", tok))
+ evmask |= CONS_EVT_MOUSE_MOVE;
+ else if (!strcasecmp ("mousebutton", tok))
+ evmask |= CONS_EVT_MOUSE_BUTTON;
+ else if (!strcasecmp ("keypress", tok))
+ evmask |= CONS_EVT_KEYPRESS;
+ else if (!strcasecmp ("output", tok))
+ evmask |= CONS_EVT_OUTPUT;
+ else
+ argp_error (state, "The event can be one of: MOUSEMOVE,"
+ " MOUSEBUTTON, KEYPRESS or OUTPUT");
+ tok = strtok (NULL, ",");
+ }
+ return evmask;
+ }
+
switch (opt)
{
case OPT_SLACK:
@@ -131,7 +180,28 @@ parse_startup_opt (int opt, char *arg, struct argp_state *state)
argp_error (state, "The visual bell can be one of: on, off, visual, "
"audible");
break;
-
+
+ case OPT_MOUSE_SHOW:
+ _cons_show_mouse = parse_events (arg);
+ break;
+
+ case OPT_MOUSE_HIDE:
+ _cons_hide_mouse = parse_events (arg);
+ break;
+
+ case OPT_MOUSE_SENS:
+ {
+ char *tail;
+
+ errno = 0;
+ _cons_mouse_sens = strtod (arg, &tail);
+ if (tail == NULL || tail == arg || *tail != '\0')
+ argp_error (state, "SENSITIVITY is not a number: %s", arg);
+ if (errno)
+ argp_error (state, "Overflow in argument SENSITIVITY %s", arg);
+ break;
+ }
+
case ARGP_KEY_ARG:
if (state->arg_num > 0)
/* Too many arguments. */
@@ -25,7 +25,7 @@
#include "priv.h"
-/* Option keys for long-only options in diskfs_common_options. */
+/* Option keys for long-only options in argp_option. */
#define OPT_SLACK 600 /* --slack */
#define OPT_JUMP_DOWN_ON_INPUT 601 /* --jump-down-on-input */